unit uadwin;


interface

{ Returns measured value of analog input "nr"                                   }
{ ==============================================================================}
FUNCTION adc(nr: WORD) : WORD;


{ Returns how busy the CPU is (processor usage in percent)                      )
{ ==============================================================================}
FUNCTION auslast : WORD;


{ Returns state of digital inputs (bits 0...15)                                 }
{ ==============================================================================}
FUNCTION dig_in : LongInt;


{ Returns state (read-back) of digital outputs (bits 0...15)                    }
{ ==============================================================================}
FUNCTION dig_out : LongInt;


{ Returns value of free memory from the ADwin-2, -4, -5 and -8 System(in bytes) }
{ ==============================================================================}
FUNCTION freemem : LongInt;

{ Returns value of free memory from the ADwin-9 (in bytes) }
{ ==============================================================================}
FUNCTION freemem_T9(typ: Word) : LongInt;

{ Sets analog output "ndac" to value "iw" (in digits)                           }
{ ==============================================================================}
FUNCTION set_dac (ndac, iw : WORD) : WORD;


{ Sets digital outputs to "iw" (bits 0...15)                                    }
{ ==============================================================================}
FUNCTION set_dig_out (iw : WORD) : WORD;


{ Sets a parameter (PAR_"npar") on the ADwin-card to "il"                       }
{ ==============================================================================}
FUNCTION set_par(npar: SmallInt; il: LongInt) : WORD;


{ Sets a float parameter (FPAR_"npar")on the ADwin-card to "iw"                 }
{ ==============================================================================}
FUNCTION set_fpar (npar : WORD; iw : SINGLE) : WORD;


{ Starts process number "nproz" on the ADwin-card                               }
{ ==============================================================================}
FUNCTION start (nproz : WORD ) : WORD;


{ Stops process number "nproz" on the ADwin-card                                }
{ ==============================================================================}
FUNCTION stop (nproz : WORD ) : WORD;


{ Returns value of parameter (PAR_"npar") from the ADwin-card                   }
{ ==============================================================================}
FUNCTION get_par(npar: SmallInt) : LongInt;


{ Returns float value of parameter (PAR_"npar") from the ADwin-card             }
{ ==============================================================================}
FUNCTION get_fpar(npar: WORD) : SINGLE;


{ Returns state of ACTIVATE_PC-flag of process number "nr"                      }
{ ==============================================================================}
FUNCTION get_activate(nr: WORD) : LongInt;


{ Down-loads an ADbasic-process (BIN-file) to the ADwin-card                    }
{ ==============================================================================}
FUNCTION ADBload(dateiname:STRING) : WORD;


{ Down-loads the operating system (BTL-file) to the ADwin-card                  }
{ ==============================================================================}
FUNCTION iserv(dateiname:STRING ; IBOARDSIZE : LONGINT) : LongInt;

{ Down-loads the operating system (BTL-file) to the ADwin-card                  }
{ ==============================================================================}
FUNCTION Boot(dateiname:STRING ; IBOARDSIZE : LONGINT) : LongInt;

{ Returns array-element(s) of WORD-type from ADwin-card-array (DATA_"ndata")    }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      Get_Data(1,1,900,@werte[1]);
      ...
}
FUNCTION  Get_Data(ndata : WORD; nstart,il :LongInt;iw : POINTER) : WORD;


{ Returns array-element(s) of LONGINT-type from ADwin-card-array (DATA_"ndata") }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LONGINT;
    begin
      lGet_Data(1,1,900,@lwerte[1]);
      ...
}
FUNCTION lGet_Data(ndata : WORD; nstart,il :LongInt;iw : POINTER) : WORD;


{ Returns array-element(s) of SINGLE-type from ADwin-card-array (DATA_"ndata")  }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of SINGLE;
    begin
      fGet_Data(1,1,900,@fwerte[1]);
      ...
}
FUNCTION fGet_Data(ndata : WORD; nstart,il :LongInt;iw : POINTER) : WORD;


{ Sets array-element(s) of ADwin-card from WORD-array                           }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      Set_Data(1,1,900,@werte[1]);
      ...
}
FUNCTION  Set_Data(ndata : WORD; istart,il :LongInt;iw : POINTER) : WORD;


{ Sets array-element(s) of ADwin-card from LONGINT-array                        }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LONGINT;
    begin
      lSet_Data(1,1,900,@lwerte[1]);
      ...
}
FUNCTION lSet_Data(ndata : WORD; istart,il :LongInt;iw : POINTER) : WORD;


{ Sets array-element(s) of ADwin-card from SINGLE-array                         }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of SINGLE;
    begin
      fSet_Data(1,1,900,@fwerte[1]);
      ...
}
FUNCTION fSet_Data(ndata : WORD; istart,il :LongInt;iw : POINTER) : WORD;


{ Returns number of stored elements in FIFO                                     }
{ ==============================================================================}
FUNCTION get_fifo_count(nfifo : WORD):LONGINT;


{ Returns number of free elements in FIFO                                       }
{ ==============================================================================}
FUNCTION get_fifo_empty(nfifo : WORD):LONGINT;


{ Initiats read and write pointer of FIFO                                       }
{ ==============================================================================}
FUNCTION clear_fifo (nfifo : WORD ) : WORD;


{ Returns array-elements out of ADwin-card-FIFO into WORD-array                 }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      if (get_fifo_count(1) > 900) then
      begin
        Get_FIFO(1,900,@werte[1]);
      end;
      ...
}
FUNCTION  Get_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;


{ Returns array-elements out of ADwin-card-FIFO into LONGINT-array              }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LongInt;
    begin
      if (get_fifo_count(1) > 900) then
      begin
        lGet_FIFO(1,900,@lwerte[1]);
      end;
      ...
}
FUNCTION lGet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;


{ Returns array-elements out of ADwin-card-FIFO into SINGLE-array               }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of Single;
    begin
      if (get_fifo_count(1) > 900) then
      begin
        fGet_FIFO(1,900,@fwerte[1]);
      end;
      ...
}
FUNCTION fGet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;


{ Sets FIFO-element(s) of ADwin-card from WORD-array                            }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      if (get_fifo_empty(1) > 900) then
      begin
        Set_FIFO(1,900,@werte[1]);
      end;
      ...
}
FUNCTION  Set_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;


{ Sets FIFO-element(s) of ADwin-card from LONGINT-array                         }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LONGINT;
    begin
      if (get_fifo_empty(1) > 900) then
      begin
        lSet_FIFO(1,900,@lwerte[1]);
      end;
      ...
}
FUNCTION lSet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;


{ Sets FIFO-element(s) of ADwin-card from SINGLE-array                          }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of Single;
    begin
      if (get_fifo_empty(1) > 900) then
      begin
        fSet_FIFO(1,900,@fwerte[1]);
      end;
      ...
}
FUNCTION fSet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;


{ Checks if the CPU is accessible (previously booted and running)               }
{ ==============================================================================}
FUNCTION Test : WORD;

{ Error messages for Test, ADBload, Boot & Net_Connect    0/1 -> (off/on)       }
{ ==============================================================================}
Procedure ErrMessage (state: Word);


{ Writes array-elements of ADwin-card immediately to harddisk                   }
{ ==============================================================================}
{  There are two choices for the parameter 'mode':
   1) mode=0 -> current file will be overwritten
   2) mode=1 -> data will be append to existing file

  e.g.:
    Save_Data('C:\DATA1.DAT', 1, 1, 1000, 1)
    ...
}
FUNCTION Save_Data(dateiname: STRING; nr: WORD; startind,count: LongInt; mode: WORD): WORD;

{ Writes array-elements of ADwin-card immediately to harddisk                   }
{ ==============================================================================}
{  There are two choices for the parameter 'mode':
   1) mode=0 -> current file will be overwritten
   2) mode=1 -> data will be append to existing file

  e.g.:
    Data2File('C:\DATA1.DAT', 1, 1, 1000, 1)
    ...
}
FUNCTION Data2File(dateiname:STRING; nr: WORD; startind,count: LongInt; mode:WORD): WORD;

{ Build a network connection to an ADwin-System in another PC (host). Before    }
{ calling this function, the program ADserver has to be started on the host PC  }
{ ==============================================================================}
Function Net_Connect(prot, addr, EPoint, PWord: String): Word;

{ Ends the network connection to the host PC                                    }
{ ==============================================================================}
Function Net_Disconnect: Word;


(* Import of functions out of ADWIN32.DLL or ADWIN.DLL *)
{}
FUNCTION ADboot(dateiname: PChar ;Linkadresse: WORD; IBOARDSIZE: LongInt; Msg: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION ADBload96(dateiname: PChar; Linkadresse: WORD; Msg: WORD): WORD; far; stdcall; external 'adwin32.dll' name 'ADBload';
FUNCTION ADTest_Version(Linkadresse, msgbox: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION ADProzessorTyp(Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION AD_Auslastung(Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION AD_Memory(Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION AD_Memory_all(typ,Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION Get_ADC(nadc, Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION Set_DAC96(nadc, iw, Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Set_DAC';
FUNCTION Set_Digout(iw, Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION Set_DigoutX(iw, Linkadresse: WORD): WORD; far; stdcall ;external 'adwin32.dll';
FUNCTION Get_Digout(Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION Get_DigoutX(Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION Get_Digin(Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION Get_DiginX(Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION ADB_Start(np, Linkadresse : WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION ADB_Stop(np, Linkadresse : WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION Start96(np, Linkadresse : WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Start';
FUNCTION Stop96(np, Linkadresse : WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Stop';
FUNCTION Set_ADBPar(np: SmallInt; iw: LongInt; Linkadresse : WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION Set_ADBFPar(np: WORD; fw: Single; Linkadresse : WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION Get_ADBPar(np: SmallInt; Linkadresse : WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION Get_ADBFPar(np, Linkadresse : WORD): Single; far; stdcall; external 'adwin32.dll';
FUNCTION Get_List(fp: pointer; typ, nadc, proc: WORD; il: LongInt; Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION Set_List(fp: pointer; typ, nadc: WORD; il: LongInt; Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll';
FUNCTION Get_Data96(fp: pointer; typ, nadc: WORD; lstart, il: LongInt; Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Get_Data';
FUNCTION Set_Data96(fp: pointer; typ, nadc: WORD; lstart, il: LongInt; Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Set_Data';
FUNCTION Get_Fifo96(fp: pointer; typ, nadc: WORD; il: LongInt; Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Get_Fifo';
FUNCTION Set_Fifo96(fp: pointer; typ, nadc: WORD; il: LongInt; Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Set_Fifo';
FUNCTION GetDataLenght(nr, Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll';
FUNCTION Get_Fifo_Count96(nr, Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll' name 'Get_Fifo_Count';
FUNCTION Get_Fifo_Empty96(nr, Linkadresse: WORD): LongInt; far; stdcall; external 'adwin32.dll' name 'Get_Fifo_Empty';
FUNCTION Clear_Fifo96(nr, Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll' name 'Clear_Fifo';
FUNCTION SaveFast(dateiname: PChar; nr: WORD; startind, count: LongInt; mode, Linkadresse: WORD): WORD; far; stdcall; external 'adwin32.dll';
Function AD_Net_Connect(prot, addr, EPoint, PWord: PChar; msgbox: Word): Word; far; stdcall; external 'adwin32.dll';
Function AD_Net_Disconnect: Word; far; stdcall; external 'adwin32.dll';


Implementation

const
  linkaddr = $150;
  append = 1;
  overwrite = 0;

var
  mess: Word = 1;

{ Returns measured value of analog input "nr"                                   }
{ ==============================================================================}
FUNCTION adc(nr: WORD) : WORD;
begin
  adc := Get_ADC(nr, linkaddr);              { Messergebnis abholen }
end;


{ Returns how busy the CPU is (processor usage in percent)                      )
{ ==============================================================================}
FUNCTION auslast : WORD;
begin
  auslast := AD_Auslastung(linkaddr);          { Ergebnis abholen }
end;


{ Returns state of digital inputs (bits 0...15)                                 }
{ ==============================================================================}
FUNCTION dig_in : LongInt;
begin
  dig_in := Get_Digin(linkaddr);           { Ergebnis abholen }
end;


{ Returns state (read-back) of digital outputs (bits 0...15)                    }
{ ==============================================================================}
FUNCTION dig_out : LongInt;
begin
  dig_out := Get_Digout(linkaddr);          { Ergebnis abholen }
end;


{ Returns value of free memory from the ADwin-2, -4, -5 and -8 System(in bytes) }
{ ==============================================================================}
FUNCTION freemem : LongInt;
begin
  freemem := AD_Memory(linkaddr);          { Ergebnis abholen }
end;

{ Returns value of free memory from the ADwin-9 System (in bytes)               }
{ ==============================================================================}
FUNCTION freemem_T9(typ: Word) : LongInt;
var
  mul: Integer;
begin
  mul:=4;
  if (typ=1) then mul:=6;
  freemem_T9 := AD_Memory_all(typ,linkaddr)*mul;          { Ergebnis abholen }
end;

{ Returns state of ACTIVATE_PC-flag of process number "nr"                      }
{ ==============================================================================}
FUNCTION get_activate(nr: WORD) : LongInt;
var
  parno: WORD;
  erg  : LongInt;
begin
  parno := -(70-nr);
  erg := Get_ADBPar(parno, linkaddr);     { Parameter holen }
  get_activate := erg;
  if (erg = 1) then set_par(parno, 0);
end;


{ Sets analog output "ndac" to value "iw" (in digits)                           }
{ ==============================================================================}
FUNCTION set_dac (ndac, iw : WORD) : WORD;
begin
  set_dac := Set_DAC96(ndac, iw, linkaddr);
end;


{ Sets digital outputs to "iw" (bits 0...15)                                    }
{ ==============================================================================}
FUNCTION set_dig_out (iw : WORD): WORD;
begin
  set_dig_out:=Set_Digout(iw, linkaddr);
end;


{ Sets a parameter (PAR_"npar") on the ADwin-card to "il"                       }
{ ==============================================================================}
FUNCTION set_par (npar : SmallInt; il : LongInt) : WORD;
begin
  set_par := Set_ADBPar(npar, il, linkaddr);
end;


{ Sets a float parameter (FPAR_"npar")on the ADwin-card to "iw"                 }
{ ==============================================================================}
FUNCTION set_fpar (npar : WORD; iw : SINGLE) : WORD;
begin
  set_fpar := Set_ADBFPar(npar, iw, linkaddr);
end;


{ Starts process number "nproz" on the ADwin-card                               }
{ ==============================================================================}
FUNCTION start (nproz : WORD ) : WORD;
begin
  start := ADB_Start(nproz, linkaddr);
end;


{ Stops process number "nproz" on the ADwin-card                                }
{ ==============================================================================}
FUNCTION stop (nproz : WORD ) : WORD;
begin
  stop := ADB_Stop(nproz, linkaddr);
end;


{ Returns value of parameter (PAR_"npar") from the ADwin-card                   }
{ ==============================================================================}
FUNCTION get_par(npar: SmallInt) : LongInt;
begin
  get_par := Get_ADBPar(npar, linkaddr);            { Parameter holen }
end;


{ Returns float value of parameter (PAR_"npar") from the ADwin-card             }
{ ==============================================================================}
FUNCTION get_fpar(npar: WORD) : Single;
begin
  get_fpar := Get_ADBFPar(npar, linkaddr);            { Parameter holen }
end;


{ Returns array-element(s) of WORD-type from ADwin-card-array (DATA_"ndata")    }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      Get_Data(1,1,900,@werte[1],$150);
      ...
}
FUNCTION Get_Data(ndata : WORD; nstart,il :LongInt;iw : POINTER) : WORD;
begin
  Get_Data := Get_Data96(iw, 1, ndata, nstart, il, linkaddr);
end;


{ Returns array-element(s) of LONGINT-type from ADwin-card-array (DATA_"ndata") }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LONGINT;
    begin
      lGet_Data(1,1,900,@lwerte[1],$150);
      ...
}
FUNCTION lGet_Data(ndata : WORD; nstart,il :LongInt;iw : POINTER) : WORD;
begin
  lGet_Data := Get_Data96(iw, 2, ndata, nstart, il, linkaddr);
end;


{ Returns array-element(s) of SINGLE-type from ADwin-card-array (DATA_"ndata")  }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of SINGLE;
    begin
      fGet_Data(1,1,900,@fwerte[1],$150);
      ...
}
FUNCTION fGet_Data(ndata : WORD; nstart,il :LongInt;iw : POINTER) : WORD;
begin
  fGet_Data := Get_Data96(iw, 5, ndata, nstart, il, linkaddr);
end;


{ Sets array-element(s) of ADwin-card from WORD-array                           }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      Set_Data(1,1,900,@werte[1],$150);
      ...
}
FUNCTION  Set_Data(ndata : WORD; istart, il :LongInt;iw : POINTER) : WORD;
begin
  Set_Data := Set_Data96(iw, 1, ndata, istart, il, linkaddr);
end;


{ Sets array-element(s) of ADwin-card from LONGINT-array                        }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LONGINT;
    begin
      lSet_Data(1,1,900,@lwerte[1],$150);
      ...
}
FUNCTION lSet_Data(ndata : WORD; istart,il :LongInt;iw : POINTER) : WORD;
begin
  lSet_Data := Set_Data96(iw, 2, ndata, istart, il, linkaddr);
end;


{ Sets array-element(s) of ADwin-card from SINGLE-array                         }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of SINGLE;
    begin
      fSet_Data(1,1,900,@fwerte[1],$150);
      ...
}
FUNCTION fSet_Data(ndata : WORD; istart,il :LongInt;iw : POINTER) : WORD;
begin
  fSet_Data := Set_Data96(iw, 5, ndata, istart, il, linkaddr);
end;


{ Returns number of stored elements in FIFO                                     }
{ ==============================================================================}
FUNCTION get_fifo_count(nfifo : WORD):LONGINT;
begin
  get_fifo_count := get_fifo_count96(nfifo, linkaddr);
end;


{ Returns number of free elements in FIFO                                       }
{ ==============================================================================}
FUNCTION get_fifo_empty(nfifo : WORD):LONGINT;
begin
  get_fifo_empty := get_fifo_empty96(nfifo, linkaddr);
end;


{ Initiats read and write pointer of FIFO                                       }
{ ==============================================================================}
FUNCTION clear_fifo (nfifo : WORD ) : WORD;
begin
  clear_fifo := clear_fifo96(nfifo, linkaddr);
end;


{ Returns array-elements out of ADwin-card-FIFO into WORD-array                 }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      if (get_fifo_count(1,$150) > 900) then
      begin
        Get_FIFO(1,900,@werte[1],$150);
      end;
      ...
}
FUNCTION  Get_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;
begin
  Get_FIFO := Get_FIFO96(iw, 1, nfifo, il, linkaddr);
end;


{ Returns array-elements out of ADwin-card-FIFO into LONGINT-array              }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LongInt;
    begin
      if (get_fifo_count(1,$150) > 900) then
      begin
        lGet_FIFO(1,900,@lwerte[1],$150);
      end;
      ...
}
FUNCTION lGet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;
begin
  lGet_FIFO := Get_FIFO96(iw, 2, nfifo, il, linkaddr);
end;


{ Returns array-elements out of ADwin-card-FIFO into SINGLE-array               }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of Single;
    begin
      if (get_fifo_count(1,$150) > 900) then
      begin
        fGet_FIFO(1,900,@fwerte[1],$150);
      end;
      ...
}
FUNCTION fGet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;
begin
  fGet_FIFO := Get_FIFO96(iw, 5, nfifo, il, linkaddr);
end;


{ Sets FIFO-element(s) of ADwin-card from WORD-array                            }
{ ==============================================================================}
{ e.g.:
    VAR
      werte : ARRAY[1..1000] of WORD;
    begin
      if (get_fifo_empty(1,$150) > 900) then
      begin
        Set_FIFO(1,900,@werte[1],$150);
      end;
      ...
}
FUNCTION  Set_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;
begin
  Set_FIFO := Set_FIFO96(iw, 1, nfifo, il, linkaddr);
end;


{ Sets FIFO-element(s) of ADwin-card from LONGINT-array                         }
{ ==============================================================================}
{ e.g.:
    VAR
      lwerte : ARRAY[1..1000] of LONGINT;
    begin
      if (get_fifo_empty(1,$150) > 900) then
      begin
        lSet_FIFO(1,900,@lwerte[1],$150);
      end;
      ...
}
FUNCTION lSet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;
begin
  lSet_FIFO := Set_FIFO96(iw, 2, nfifo, il, linkaddr);
end;


{ Sets FIFO-element(s) of ADwin-card from SINGLE-array                          }
{ ==============================================================================}
{ e.g.:
    VAR
      fwerte : ARRAY[1..1000] of Single;
    begin
      if (get_fifo_empty(1,$150) > 900) then
      begin
        fSet_FIFO(1,900,@fwerte[1],$150);
      end;
      ...
}
FUNCTION fSet_FIFO(nfifo : WORD; il :LongInt;iw : POINTER) : WORD;
begin
  fSet_FIFO := Set_FIFO96(iw, 5, nfifo, il, linkaddr);
end;


{ Down-loads an ADbasic-process (BIN-file) to the ADwin-card                    }
{ ==============================================================================}
FUNCTION ADBload(dateiname:STRING) : WORD;
var
  dna  : PChar;
begin
  dateiname := dateiname +  Chr(0);		{ convert filename into CString }
  dna := @dateiname[1];
  ADBload:= ADBload96(dna,linkaddr,mess);		{ load }
end;

{ Down-loads the operating system (BTL-file) to the ADwin-card                  }
{ ==============================================================================}
FUNCTION ISERV(dateiname:STRING ; IBOARDSIZE : LONGINT) : LongInt;
var
  dna : PChar;
begin
  dateiname := dateiname +  Chr(0);		{ convert filename into CString }
  dna := @dateiname[1];
  ISERV := ADboot(dna,linkaddr,IBOARDSIZE,mess);	{ boot ADwin-card }
end;

{ Down-loads the operating system (BTL-file) to the ADwin-card                  }
{ ==============================================================================}
FUNCTION Boot(dateiname:STRING ; IBOARDSIZE : LONGINT) : LongInt;
begin
  Boot := ADboot(PChar(dateiname),linkaddr,IBOARDSIZE,mess);	{ boot ADwin-card }
end;

{ Error messages for Test, ADBload, Boot & Net_Connect    0/1 -> (off/on)       }
{ ==============================================================================}
Procedure ErrMessage (state: Word);
begin
  mess := state;
end;

{ Checks if the CPU is accessible (previously booted and running)               }
{ ==============================================================================}
FUNCTION Test : WORD;
begin
  Test := ADTest_Version(linkaddr, mess);
end;

{ Writes array-elements of ADwin-card immediately to harddisk                   }
{ ==============================================================================}
FUNCTION Save_Data(dateiname:STRING; nr: WORD; startind,count: LongInt; mode:WORD): WORD;
var
  dna : PChar;
begin
  dateiname := dateiname +  Chr(0);		{ convert filename into CString }
  dna := @dateiname[1];
  Save_Data := SaveFast(dna,nr,startind,count,mode,linkaddr);
end;

{ Writes array-elements of ADwin-card immediately to harddisk                   }
{ ==============================================================================}
FUNCTION Data2File(dateiname:STRING; nr: WORD; startind,count: LongInt; mode:WORD): WORD;
begin
  Data2File := SaveFast(PChar(dateiname),nr,startind,count,mode,linkaddr);
end;

{ Build a network connection to an ADwin-System in another PC (host). Before    }
{ calling this function, the program ADserver has to be started on the host PC  }
{ ==============================================================================}
Function Net_Connect(prot, addr, EPoint, PWord: String): Word;
begin
  Net_Connect := AD_Net_Connect(PChar(prot), PChar(addr), PChar(EPoint), PChar(PWord), mess);
end;

{ Ends the network connection to the host PC                                    }
{ ==============================================================================}
Function Net_Disconnect: Word;
begin
  Net_Disconnect := AD_Net_Disconnect();
end;

end.
